**************
Triage Process
**************

The issue and PR triage processes are driven by the `Ansibot <https://github.com/ansible/ansibullbot>`_. Whenever an issue or PR is filed, the Ansibot examines the issue to ensure that all relevant data is present, and handles the routing of the issue as it works its way to eventual completion.

For details on how Ansibot manages the triage process, please consult the `Ansibot
Issue Guide <https://github.com/ansible/ansibullbot/blob/master/ISSUE_HELP.md>`_.
